function [yhat regions]=eval_local_lda(Fc,Fr,x)

% This code is based on the paper: J. Wang, V. Saligrama, Local Supervised
% Learning through Space Partitioning, in NIPS, pp. 91-99, 2012.

% Inputs:
% Fc: local classification structure (first output from local_lda.m)
% Fr: local partitioning structure (second output from local_lda.m)
% x: d x n data

% Outputs:
% yhat: 1 x n predicted labels
% regions: 1 x n partitioned regions

region_labels=zeros(length(Fr),size(x,2));

for i=1:length(Fr)
    if i>1
        region_labels(i,:)=(eval_multiclass_lda(Fr(i),x)==-1).*(sum(region_labels(1:i-1,:),1)==0);
    else
        region_labels(i,:)=eval_multiclass_lda(Fr(i),x)==-1;
    end
end
region_labels=[region_labels;(sum(region_labels,1)==0)];
[~,regions]=max(region_labels);





yhat_full=zeros(length(Fc),size(x,2));

for i=1:length(Fc)
    yhat_full(i,:)=eval_multiclass_lda(Fc(i),x);
end

yhat=sum(region_labels.*yhat_full,1);


function [yhat deltas]=eval_multiclass_lda(F,x)

if isempty(F(1).labels)
    yhat=zeros(1,size(x,2));
    deltas=zeros(1,size(x,2));
    return;
end

%F=struct('labels',{},'mu',{},'pi',{},'sigma_inv',{});


% deltas=zeros(length(F(1).labels),size(x,2));

if size(.5*diag(F(1).mu'*F(1).sigma_inv*F(1).mu),1)==0
    disp('trouble');
end


offsets=.5*diag(F(1).mu'*F(1).sigma_inv*F(1).mu)-log(F(1).pi);

deltas=(x'*F(1).sigma_inv*F(1).mu)'-repmat(offsets,1,size(x,2));

[~,ind]=max(deltas,[],1);
labels=F(1).labels;
yhat=labels(ind);


